==> 0.0.3.tar.gz: lib/OCRKitController.dart <==
import 'package:ocrkit/OCRKitView.dart';

///This controller is used to control CameraKiView.dart
class OCRKitController {
  OCRKitView cameraKitView;

  ///pause camera while stop camera preview.
  ///Plugin manage automatically pause camera based android, iOS lifecycle and widget visibility
  pauseCamera() {
    cameraKitView.viewState.controller.setCameraVisible(false);
  }

  ///Closing camera and dispose all resource
  closeCamera() {
    cameraKitView.viewState.controller.closeCamera();
  }

  ///resume camera while resume camera preview.
  ///Plugin manage automatically resume camera based android, iOS lifecycle and widget visibility
  resumeCamera() {
    cameraKitView.viewState.controller.setCameraVisible(true);
  }

  ///Use this method for taking picture in take picture mode
  ///This method return path of image
  Future<String> takePicture() {
    return cameraKitView.viewState.controller.takePicture();
  }

  ///Change flash mode between auto, on and off
  changeFlashMode(CameraFlashMode captureFlashMode) {
    cameraKitView.viewState.controller.changeFlashMode(captureFlashMode);
  }

  ///Connect view to this controller
  void setView(OCRKitView cameraKitView) {
    this.cameraKitView = cameraKitView;
  }
  ///Enable and disable scanning for text in live mode.
  void setScanForText(bool isScanningForText) {
    cameraKitView.viewState.controller.setScanForText(isScanningForText);
  }

  // initCamera() {
  //   cameraKitView.viewState.controller.initCamera();
  // }
}

==> 0.0.5.tar.gz: lib/OCRKitController.dart <==
import 'package:ocrkit/OCRKitView.dart';

///This controller is used to control CameraKiView.dart
class OCRKitController {
  OCRKitView cameraKitView;

  ///pause camera while stop camera preview.
  ///Plugin manage automatically pause camera based android, iOS lifecycle and widget visibility
  pauseCamera() {
    cameraKitView.viewState.controller.setCameraVisible(false);
  }

  ///Closing camera and dispose all resource
  closeCamera() {
    cameraKitView.viewState.controller.closeCamera();
  }

  ///resume camera while resume camera preview.
  ///Plugin manage automatically resume camera based android, iOS lifecycle and widget visibility
  resumeCamera() {
    cameraKitView.viewState.controller.setCameraVisible(true);
  }

  ///Use this method for taking picture in take picture mode
  ///This method return path of image
  Future<String> takePicture({String path = ""}) {
    return cameraKitView.viewState.controller.takePicture(path);
  }

  ///Change flash mode between auto, on and off
  changeFlashMode(CameraFlashMode captureFlashMode) {
    cameraKitView.viewState.controller.changeFlashMode(captureFlashMode);
  }

  ///Connect view to this controller
  void setView(OCRKitView cameraKitView) {
    this.cameraKitView = cameraKitView;
  }
  ///Enable and disable scanning for text in live mode.
  void setScanForText(bool isScanningForText) {
    cameraKitView.viewState.controller.setScanForText(isScanningForText);
  }

  // initCamera() {
  //   cameraKitView.viewState.controller.initCamera();
  // }
}
